==> haskell-crypto-api-tests-0.3-356-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-api-tests
version:              0.3
visibility:           public
id:                   crypto-api-tests-0.3-4xuWz29ePVV9Ph9ODzREPX
key:                  crypto-api-tests-0.3-4xuWz29ePVV9Ph9ODzREPX
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             http://trac.haskell.org/crypto-api/wiki
synopsis:             A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).

category:             Data, Cryptography
abi:                  50e30792d0712565b65d0fae474f42ff
exposed:              True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish

hidden-modules:       Paths_crypto_api_tests
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-api-tests-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-api-tests-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-api-tests
hs-libraries:         HScrypto-api-tests-0.3-4xuWz29ePVV9Ph9ODzREPX
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    bytestring-0.11.5.3 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix directory-1.3.8.5
    filepath-1.4.300.1 test-framework-0.8.2.2-ITHWZraIqyRCzzqSShCGFx
    test-framework-hunit-0.3.0.2-6aaATLwpnqw3PPYB2HkLCt
    test-framework-quickcheck2-0.3.0.6-H0xH8C2gPJGnaEmTKj6PE

haddock-interfaces:
    /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock

haddock-html:         /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-357-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-api-tests
version:              0.3
visibility:           public
id:                   crypto-api-tests-0.3-2UmjOhZzLfi2i14t1hY2nJ
key:                  crypto-api-tests-0.3-2UmjOhZzLfi2i14t1hY2nJ
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             http://trac.haskell.org/crypto-api/wiki
synopsis:             A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).

category:             Data, Cryptography
abi:                  eeced0e0345550dd09e553f35675496c
exposed:              True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish

hidden-modules:       Paths_crypto_api_tests
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypto-api-tests-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypto-api-tests-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-api-tests
hs-libraries:         HScrypto-api-tests-0.3-2UmjOhZzLfi2i14t1hY2nJ
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    bytestring-0.11.5.3 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix directory-1.3.8.5
    filepath-1.4.300.1 test-framework-0.8.2.2-8fX8NEZ5OtDCOpAj0ijyRX
    test-framework-hunit-0.3.0.2-2872p9r6J3I6VKD17s7qNh
    test-framework-quickcheck2-0.3.0.6-BKrfvnLN9P2avPtTOpexE

haddock-interfaces:
    /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock

haddock-html:         /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
